<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main Metize Core Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */
final class Metize_Extension {

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Elementor_Test_Extension The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Test_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}


	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

		// Add Plugin actions
		add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );

        // Register widget scripts
		add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'widget_scripts' ]);

        // category register
		add_action( 'elementor/elements/categories_registered',[ $this, 'metize_elementor_widget_categories' ] );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'metize' ),
			'<strong>' . esc_html__( 'Metize Core', 'metize' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'metize' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'metize' ),
			'<strong>' . esc_html__( 'Metize Core', 'metize' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'metize' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'metize' ),
			'<strong>' . esc_html__( 'Metize Core', 'metize' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'metize' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets() {

		
		
		
		// ------------------------------------------start header file------------------------------------------start //
		// Header Elements
		require_once( METIZE_ADDONS . '/header/header.php' );

		// Header Widget Register
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Header() );

		// ------------------------------------------end header file------------------------------------------start //



		// ------------------------------------------start footer file------------------------------------------start //
		// Footer Elements
		require_once( METIZE_ADDONS . '/footer-widgets/newsletter-widget.php' );
		// Footer Widget Register
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Newsletter_Widgets() );

		// ------------------------------------------end  footer file------------------------------------------start //



		// Include Widget files
		// require_once( METIZE_ADDONS . '/widgets/section-title.php' );
		require_once( METIZE_ADDONS . '/widgets/blog-post.php' );
		// require_once( METIZE_ADDONS . '/widgets/button.php' );


		require_once( METIZE_ADDONS . '/widgets/metize-banner.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-features.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-app-features.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-service2.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-counterup.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-testimonials.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-pricing.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-contact-info.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-partner.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-wwo.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-wcu.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-about-us.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-services.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-project-v2.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-team.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-faq.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-team-details.php' );
		require_once( METIZE_ADDONS . '/widgets/metize-qualifications.php' );
		// require_once( METIZE_ADDONS . '/widgets/metize-workprocess.php' );
		// require_once( METIZE_ADDONS . '/widgets/metize-projects.php' );
		// require_once( METIZE_ADDONS . '/widgets/metize-experience.php' );
		// require_once( METIZE_ADDONS . '/widgets/metize-contact-me.php' );
		// require_once( METIZE_ADDONS . '/widgets/metize-project-info.php' );


		
		


		// Register widget
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Section_Title_Widget() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Blog_Post() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Button() );


		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Banner() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Features() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_App_Features() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Offer() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Counterup() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Testimonials() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Pricing_Plan() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Contact_Info() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Client_Logo() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Features_Ww0() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Wcu() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_About_Us() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Services() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Project_V2() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Team() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Faq() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Team_Info() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Qualifications() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Work_Process() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Projects() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Team() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Experience() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Portfolio_Hireme() );
		// \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Metize_Project_Info() );




		
		
		

		

	}

    public function widget_scripts() {
        wp_enqueue_script(
            'metize-frontend-script',
            METIZE_PLUGDIRURI . 'assets/js/metize-frontend.js',
            array('jquery'),
            false,
            true
		);
	}
	

    function metize_elementor_widget_categories( $elements_manager ) {
        $elements_manager->add_category(
            'metize',
            [
                'title' => __( 'Metize', 'metize' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );
        $elements_manager->add_category(
            'metize_footer_elements',
            [
                'title' => __( 'Metize Footer Elements', 'metize' ),
                'icon' 	=> 'fa fa-plug',
            ]
		);

		$elements_manager->add_category(
            'metize_header_elements',
            [
                'title' => __( 'Metize Header Elements', 'metize' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );

	}

}

Metize_Extension::instance();